pypusher documented
===================

*pypusher pushes stuff from Python*

This module allows you to send Apple Push Notifications to various Apple devices from your Python code.

It relies upon *libcapn* to feature *Apple Push Notification Service* support.



Requirements
------------

1. Python 3
2. capn library - http://libcapn.org/



Contents
--------

.. toctree::
   :maxdepth: 3

   getting_started
   apple_notifications



Get involved into pypusher
--------------------------

**Submit issues.** If you spotted something weird in library behavior or want to propose a feature you can do that at https://github.com/idlesign/pypusher/issues

**Write code.** If you are eager to participate in library development, fork it at https://github.com/idlesign/pusher, write some code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish it.



The tip
-------

Sick and tired of apples? Have some bananas.
